@@ -4,7 +4,7 @@ Created on 2020-11-9
 
 @author: zhys513(254851907@qq.com)
 '''
-from opspipe.reg.common import regularExtrator
+from opspipe.reg.common import RegularExtrator
 from unittest import TestCase 
 import unittest
 
@@ -13,7 +13,7 @@ text = '急寻特朗普，男孩，于2018年11月27号11时在陕西省安康
 class TestMain(TestCase):
     
     def test_set_txt(self): 
-        ex = regularExtrator(text)  
+        ex = RegularExtrator(text)  
         ex.print_txt()
         ex.set_txt('0000').print_txt()
         self.assertEqual(ex.text,'0000')
