@@ -5,7 +5,7 @@ Created on 2020-11-9
 @author: zhys513(254851907@qq.com)
 '''
 
-from opspipe.reg.common import regularExtrator 
+from opspipe.reg.common import RegularExtrator 
 from unittest import TestCase 
 import unittest
  
@@ -14,7 +14,7 @@ text = '急寻特朗普，男孩，于2018年11月27号11时在陕西省安康
 class TestMain(TestCase):
     
     def test_set_txt(self): 
-        ex = regularExtrator(text)
+        ex = RegularExtrator(text)
         print("chinese cellphone:")
         print(ex.extract_chinese_cellphone())
         print("email:")
