@@ -15,12 +15,41 @@ from .core.events.events import create_stop_app_handler, create_start_app_handle
 from .core.logging.logging import LoggerFactory 
 from .core.router.router import router 
 from .core.middleware.middleware import init_middlewares
-
+from fastapi.staticfiles import StaticFiles
+from fastapi.openapi.docs import (
+    get_redoc_html,
+    get_swagger_ui_html,
+    get_swagger_ui_oauth2_redirect_html,
+)
 import json,yaml    
 from .core.openapi.converter import Converter   
- 
+
 # 初始化应用
-application = FastAPI(title=config.PROJECT_NAME, version=config.VERSION, description=config.DESCRIPTION)
+application = FastAPI(title=config.PROJECT_NAME, version=config.VERSION, description=config.DESCRIPTION,docs_url=None, redoc_url=None)
+
+@application.get("/docs", include_in_schema=False)
+async def custom_swagger_ui_html():
+    return get_swagger_ui_html(
+        openapi_url=application.openapi_url,
+        title=application.title + " - Swagger UI",
+        oauth2_redirect_url=application.swagger_ui_oauth2_redirect_url,
+        swagger_js_url=f"/{config.SWAGGER}/swagger-ui-bundle.js",
+        swagger_css_url=f"/{config.SWAGGER}/swagger-ui.css",
+    )
+
+
+@application.get(application.swagger_ui_oauth2_redirect_url, include_in_schema=False)
+async def swagger_ui_redirect():
+    return get_swagger_ui_oauth2_redirect_html()
+
+
+@application.get("/redoc", include_in_schema=False)
+async def redoc_html():
+    return get_redoc_html(
+        openapi_url=application.openapi_url,
+        title=application.title + " - ReDoc",
+        redoc_js_url=f"/{config.SWAGGER}/redoc.standalone.js",
+    ) 
  
 # 注入
 def get_application() -> FastAPI:
@@ -36,8 +65,11 @@ def get_application() -> FastAPI:
     # 添加错误处理
     application.add_exception_handler(HTTPException, http_error_handler)
     application.add_exception_handler(RequestValidationError, http422_error_handler) 
-    application.add_exception_handler(UnicornException, unicorn_exception_handler)
- 
+    application.add_exception_handler(UnicornException, unicorn_exception_handler) 
+    # swagger 本地化
+    swagger_dir = os.path.join(os.path.abspath(os.path.dirname(__file__)),config.SWAGGER)
+    application.mount(f"/{config.SWAGGER}", StaticFiles(directory=swagger_dir), name=f"/{config.SWAGGER}")
+
     return application
     
 def create_md_doc():  
