@@ -114,6 +114,7 @@ imgPath 图像要保存的文件夹
 zoom_x x方向的缩放系数
 zoom_y y方向的缩放系数
 rotation_angle 旋转角度
+TODO 性能较慢，需要优化
 '''
 @logtime
 def pdf_image(pdfPath,imgPath,zoom_x = 5,zoom_y = 5,rotation_angle = 0):
@@ -137,6 +138,43 @@ def pdf_image(pdfPath,imgPath,zoom_x = 5,zoom_y = 5,rotation_angle = 0):
     
     return D
 
+@logtime
+def is_img_pdf(path):
+    '''
+    #  根据pdf中图片数量判断是否是双层PDF
+    TODO 存在一定的错误性（折中方案）
+    :param path: pdf的路径 
+    :return:
+    ''' 
+    # 使用正则表达式来查找图片
+    checkXO = r"/Type(?= */XObject)" 
+    checkIM = r"/Subtype(?= */Image)"  
+    
+    # 打开pdf
+    doc = fitz.open(path)
+    # 图片计数
+    imgcount = 0
+    lenXREF = doc._getXrefLength()
+    
+    # 遍历每一个对象
+    for i in range(1, lenXREF):
+        # 定义对象字符串
+        text = doc._getXrefString(i)
+        isXObject = re.search(checkXO, text)
+        # 使用正则表达式查看是否是图片
+        isImage = re.search(checkIM, text)
+ 
+        # 如果不是对象也不是图片，则continue
+        if not isXObject or not isImage:
+            continue
+        imgcount += 1   
+    
+    print("文件名:{}, 页数: {}, 对象: {}, 图片:{}".format(path, len(doc), lenXREF - 1,imgcount))
+    if len(doc) == imgcount:
+        return True
+    else :
+        return False
+    
 def copy_dirs(src_path,target_path):
     '''拷贝指定文件夹中的文件到指定目录，没有目录结构'''
     file_count=0
